import * as i0 from '@angular/core';
import { Directive, Input, EventEmitter, signal, Component, ChangeDetectionStrategy, ContentChildren, Output, NgModule } from '@angular/core';
import { style, animateChild, query, transition, trigger, animate } from '@angular/animations';
import * as i1 from '@angular/common';
import { NgIf, NgTemplateOutlet, NgStyle } from '@angular/common';

const styleFadeNotVisible = style({ opacity: 0 });
const styleFadeVisible = style({ opacity: 1 });
const styleSlideNotVisible = style({ transform: 'translateY(100px)' });
const styleSlideVisible = style({ transform: 'translateY(0)' });
const fadeAnimationTiming = '0.25s ease';
const slideAnimationTiming = '0.5s ease';
function modalOpenCloseAnimation() {
    return [
        trigger('openClose', [
            transition(':enter, :leave', query('@*', animateChild())),
        ]),
        trigger('fade', [
            transition(':enter', [
                styleFadeNotVisible,
                animate(fadeAnimationTiming, styleFadeVisible)
            ]),
            transition(':leave', [
                styleFadeVisible,
                animate(fadeAnimationTiming, styleFadeNotVisible)
            ])
        ]),
        trigger('slideBottom', [
            transition(':enter', [
                styleSlideNotVisible,
                animate(slideAnimationTiming, styleSlideVisible)
            ]),
            transition(':leave', [
                styleSlideVisible,
                animate(slideAnimationTiming, styleSlideNotVisible)
            ])
        ])
    ];
}

class ModalTemplate {
    set name(name) {
        this._name = name;
    }
    get name() {
        return this._name;
    }
    constructor(templateRef) {
        this.templateRef = templateRef;
        this._name = undefined;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalTemplate, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.0.8", type: ModalTemplate, selector: "ng-template[spModalTemplate]", inputs: { name: ["spModalTemplate", "name"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalTemplate, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[spModalTemplate]'
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }], propDecorators: { name: [{
                type: Input,
                args: ['spModalTemplate']
            }] } });
class ModalComponent {
    constructor() {
        this.visibleChange = new EventEmitter();
        this.visible$ = signal(false);
        this.closable$ = signal(true);
        this.blocking$ = signal(true);
        this.panelStyle$ = signal(null);
        this.headerTemplate$ = signal(null);
        this.contentTemplate$ = signal(null);
        this.footerTemplate$ = signal(null);
    }
    set visible(visible) {
        this.visible$.set(visible);
    }
    set closable(closable) {
        this.closable$.set(closable);
    }
    set blocking(blocking) {
        this.blocking$.set(blocking);
    }
    set panelStyle(panelStyle) {
        this.panelStyle$.set(panelStyle);
    }
    ngAfterContentInit() {
        this.modalTemplates?.forEach((item) => {
            switch (item.name) {
                case 'header':
                    this.headerTemplate$.set(item.templateRef);
                    break;
                case 'content':
                    this.contentTemplate$.set(item.templateRef);
                    break;
                case 'footer':
                    this.footerTemplate$.set(item.templateRef);
                    break;
                default:
                    this.contentTemplate$.set(item.templateRef);
                    break;
            }
        });
    }
    backdropClicked() {
        if (!this.closable$()) {
            return;
        }
        this.close();
    }
    close() {
        this.visible = false;
        this.visibleChange.emit(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.0.8", type: ModalComponent, selector: "sp-modal", inputs: { visible: "visible", closable: "closable", blocking: "blocking", panelStyle: "panelStyle" }, outputs: { visibleChange: "visibleChange" }, queries: [{ propertyName: "modalTemplates", predicate: ModalTemplate }], ngImport: i0, template: "@if (visible$()) {\r\n    <div class=\"sp-modal\" [class.modal-blocking]=\"blocking$()\" @openClose>\r\n        @if (blocking$()) {\r\n            <div class=\"sp-modal-backdrop\" (click)=\"backdropClicked()\" @fade></div>\r\n        }\r\n        <div [ngStyle]=\"panelStyle$()\" class=\"sp-modal-panel\" @fade @slideBottom>\r\n            @if (closable$() || headerTemplate$() != null) {\r\n                <div class=\"modal-header\">\r\n                    @if (headerTemplate$() != null) {\r\n                        <div>\r\n                            <ng-container *ngTemplateOutlet=\"headerTemplate$()\"></ng-container>\r\n                        </div>\r\n                    }\r\n                    <span class=\"modal-header-spacer\"></span>\r\n                    @if (closable$()) {\r\n                        <button class=\"sp-button fab button-text button-secondary modal-button-close\" (click)=\"close()\">\r\n                            <svg viewBox=\"0 0 26 26\" class=\"sp-button-icon\" style=\"fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2\">\r\n                                <path d=\"M24.042 1.414a2 2 0 0 0-2.828 0l-19.8 19.8a2 2 0 0 0 2.829 2.828l19.799-19.8a2 2 0 0 0 0-2.828z\"/>\r\n                                <path d=\"M1.414 1.414a2 2 0 0 0 0 2.828l19.8 19.8a2 2 0 0 0 2.828-2.829L4.24 1.413a1.998 1.998 0 0 0-2.825 0l-.002.001z\"/>\r\n                            </svg>\r\n                        </button>\r\n                    }\r\n                </div>\r\n            }\r\n            <div class=\"modal-content\">\r\n                <ng-container *ngTemplateOutlet=\"contentTemplate$()\"></ng-container>\r\n            </div>\r\n            @if (footerTemplate$() != null) {\r\n                <div class=\"modal-footer\">\r\n                    <ng-container *ngTemplateOutlet=\"footerTemplate$()\"></ng-container>\r\n                </div>\r\n            }\r\n        </div>\r\n    </div>\r\n}\r\n", styles: [".modal-button-close{width:32px;height:32px}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }], animations: [modalOpenCloseAnimation()], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sp-modal', changeDetection: ChangeDetectionStrategy.OnPush, animations: [modalOpenCloseAnimation()], template: "@if (visible$()) {\r\n    <div class=\"sp-modal\" [class.modal-blocking]=\"blocking$()\" @openClose>\r\n        @if (blocking$()) {\r\n            <div class=\"sp-modal-backdrop\" (click)=\"backdropClicked()\" @fade></div>\r\n        }\r\n        <div [ngStyle]=\"panelStyle$()\" class=\"sp-modal-panel\" @fade @slideBottom>\r\n            @if (closable$() || headerTemplate$() != null) {\r\n                <div class=\"modal-header\">\r\n                    @if (headerTemplate$() != null) {\r\n                        <div>\r\n                            <ng-container *ngTemplateOutlet=\"headerTemplate$()\"></ng-container>\r\n                        </div>\r\n                    }\r\n                    <span class=\"modal-header-spacer\"></span>\r\n                    @if (closable$()) {\r\n                        <button class=\"sp-button fab button-text button-secondary modal-button-close\" (click)=\"close()\">\r\n                            <svg viewBox=\"0 0 26 26\" class=\"sp-button-icon\" style=\"fill-rule:evenodd;clip-rule:evenodd;stroke-linejoin:round;stroke-miterlimit:2\">\r\n                                <path d=\"M24.042 1.414a2 2 0 0 0-2.828 0l-19.8 19.8a2 2 0 0 0 2.829 2.828l19.799-19.8a2 2 0 0 0 0-2.828z\"/>\r\n                                <path d=\"M1.414 1.414a2 2 0 0 0 0 2.828l19.8 19.8a2 2 0 0 0 2.828-2.829L4.24 1.413a1.998 1.998 0 0 0-2.825 0l-.002.001z\"/>\r\n                            </svg>\r\n                        </button>\r\n                    }\r\n                </div>\r\n            }\r\n            <div class=\"modal-content\">\r\n                <ng-container *ngTemplateOutlet=\"contentTemplate$()\"></ng-container>\r\n            </div>\r\n            @if (footerTemplate$() != null) {\r\n                <div class=\"modal-footer\">\r\n                    <ng-container *ngTemplateOutlet=\"footerTemplate$()\"></ng-container>\r\n                </div>\r\n            }\r\n        </div>\r\n    </div>\r\n}\r\n", styles: [".modal-button-close{width:32px;height:32px}\n"] }]
        }], propDecorators: { modalTemplates: [{
                type: ContentChildren,
                args: [ModalTemplate]
            }], visible: [{
                type: Input
            }], closable: [{
                type: Input
            }], blocking: [{
                type: Input
            }], panelStyle: [{
                type: Input
            }], visibleChange: [{
                type: Output
            }] } });

class ModalModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.0.8", ngImport: i0, type: ModalModule, declarations: [ModalComponent,
            ModalTemplate], imports: [NgIf,
            NgTemplateOutlet,
            NgStyle], exports: [ModalComponent,
            ModalTemplate] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.0.8", ngImport: i0, type: ModalModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ModalComponent,
                        ModalTemplate
                    ],
                    imports: [
                        NgIf,
                        NgTemplateOutlet,
                        NgStyle
                    ],
                    exports: [
                        ModalComponent,
                        ModalTemplate
                    ]
                }]
        }] });

/*
 * Public API Surface of modal
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ModalComponent, ModalModule, ModalTemplate };
//# sourceMappingURL=spicysources-modal.mjs.map
